@@ -1,12 +1,20 @@
+# Copyright (c) 2020 Edwin Wise
+# MIT License
+# See LICENSE for details
+"""
+    Touchscreen for the official Raspberry PI 4's 7" touchscreen hardware.
+
+    Based VERY CLOSELY on the Pimoroni hp4ts.py (see the Pimoroni folder)
+"""
 import errno
 import glob
 import io
-import os
 import queue
 import select
 import struct
 import threading
 from collections import namedtuple
+from pathlib import Path
 
 import pygame
 
@@ -26,6 +34,7 @@ ABS_MT_POSITION_X = 0x35  # 53 Center X of multi touch position
 ABS_MT_POSITION_Y = 0x36  # 54 Center Y of multi touch position
 ABS_MT_TRACKING_ID = 0x39  # 57 Unique ID of initiated contact
 
+# Touch events
 TS_PRESS = 1
 TS_RELEASE = 0
 TS_MOVE = 2
@@ -132,10 +141,7 @@ class Touchscreen(object):
         self._event_queue = queue.Queue()
         self._touch_slot = 0
 
-        pygame.init()
-
         self.surface = pygame.display.set_mode(self.size, pygame.FULLSCREEN)
-
         pygame.mouse.set_visible(False)
 
     def _run(self):
@@ -192,6 +198,7 @@ class Touchscreen(object):
         return self._f_poll.poll(timeout)
 
     def poll(self):
+
         self._get_pending_events()
 
         while not self._event_queue.empty():
@@ -227,10 +234,9 @@ class Touchscreen(object):
     def _touch_device(self):
         for evdev in glob.glob("/sys/class/input/event*"):
             try:
-                with io.open(os.path.join(evdev, 'device', 'name'), 'r') as f:
+                with Path(evdev, 'device', 'name').open(mode='r') as f:
                     if f.read().strip() == self._device:
-                        return os.path.join('/dev', 'input',
-                                            os.path.basename(evdev))
+                        return str(Path('/dev', 'input', Path(evdev).name))
             except IOError as e:
                 if e.errno != errno.ENOENT:
                     raise
@@ -242,6 +248,8 @@ class Touchscreen(object):
 
 
 if __name__ == "__main__":
+    """ Test for Touchscreen.
+    """
     import signal
 
     ts = Touchscreen()
