@@ -90,12 +90,14 @@ class Button(IButtonWidget):
             self.render_focus(surface)
 
     def set(self):
+        print(f"### BUTTON SET")
         if self.behavior == Button.TOGGLE:
             self.active = True
             if self.function:
                 return self.function(self, self.active)
 
     def clear(self):
+        print(f"### BUTTON CLEAR")
         if self.behavior == Button.TOGGLE:
             self.active = False
             if self.function:
@@ -112,6 +114,7 @@ class Button(IButtonWidget):
         self.press()
 
     def press(self):
+        print(f"### BUTTON PRESS")
         if self.behavior == self.HOLD:
             self.active = True
             if self.function:
@@ -122,13 +125,15 @@ class Button(IButtonWidget):
         return self.release()
 
     def release(self):
+        print(f"### BUTTON RELEASE")
         if self.behavior == self.TOGGLE:
             self.active = not self.active
+            print(f"### ... TOGGLE {self.label} TO {self.active}")
         else:
             self.active = False
-        if self.function:
-            return self.function(self, False)
         self._pressed = False
+        if self.function:
+            return self.function(self, self.active)
 
 
 class ButtonGroup(IWidgetInterface):
